Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/build
diff options
context:
space:
mode:
Diffstat (limited to 'build')
-rwxr-xr-xbuild/integration/run-docker.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/build/integration/run-docker.sh b/build/integration/run-docker.sh
index 308749fd810..7dd270b0202 100755
--- a/build/integration/run-docker.sh
+++ b/build/integration/run-docker.sh
@@ -213,8 +213,9 @@ trap cleanUp EXIT
cd "$(dirname $0)"
# "--image XXX" option can be provided to set the Docker image to use to run
-# the integration tests (one of the "nextcloudci/phpX.Y:phpX.Y-Z" images).
-NEXTCLOUD_LOCAL_IMAGE="nextcloudci/php7.3:php7.3-5"
+# the integration tests (one of the "nextcloudci/phpX.Y:phpX.Y-Z" or
+# "ghcr.io/nextcloud/continuous-integration-integration-phpX.Y:latest" images).
+NEXTCLOUD_LOCAL_IMAGE="ghcr.io/nextcloud/continuous-integration-integration-php7.4:latest"
if [ "$1" = "--image" ]; then
NEXTCLOUD_LOCAL_IMAGE=$2